summaryrefslogtreecommitdiffstats
path: root/envsetup.sh
diff options
context:
space:
mode:
Diffstat (limited to 'envsetup.sh')
-rw-r--r--envsetup.sh5
1 files changed, 3 insertions, 2 deletions
diff --git a/envsetup.sh b/envsetup.sh
index 07c481d..3c26036 100644
--- a/envsetup.sh
+++ b/envsetup.sh
@@ -1810,8 +1810,9 @@ function dopush()
# Get target file name (i.e. system/bin/adb)
TARGET=$(echo $FILE | sed "s#$OUT/##")
- # Don't send files that are not in /system.
- if ! echo $TARGET | egrep '^system\/' > /dev/null ; then
+ # Don't send files that are not under /system or /data
+ if [ ! "echo $TARGET | egrep '^system\/' > /dev/null" -o \
+ "echo $TARGET | egrep '^data\/' > /dev/null" ] ; then
continue
else
case $TARGET in